{% extends 'otp_auth/base.html' %}
{% load widget_tweaks %}

{% block title %}Inicio de sesión{% endblock %}

{% block content %}
<form class="form" method="post" action="">
    {% csrf_token %}
    <div class="field">
        <label class="field__label">Ingresa tu número de celular.</label>
        <div class="field__columns">
            <div class="field__col">
                <div class="select">
                    {% render_field form.country_code %}
                </div>
            </div>
            <div class="field__col">
                {% render_field form.phone_number %}
            </div>
        </div>
        {{ form.country_code.errors }}
        {{ form.phone_number.errors }}
    </div>
    <div class="form__action">
        <button class="btn btn_is-full-width form__btn" type="submit">Enviar mensaje</button>
    </div>
</form>
{% endblock %}
