// Fonts
$font: 'Proxima Nova', Arial, Helvetica, sans-serif

// Colors
$white: #fff
$black: #000
$red:   #f00

$gray-100: #ebebeb
$gray-200: #6f6f6e
$gray-300: #525252
$gray-400: #2b2b2b

// Forms
$text-inputs-list: ('[type="color"]', '[type="date"]', '[type="datetime"]', '[type="datetime-local"]', '[type="email"]', '[type="month"]', '[type="number"]', '[type="password"]', '[type="search"]', '[type="tel"]', '[type="text"]', '[type="time"]', '[type="url"]', '[type="week"]', 'input:not([type])', 'select', 'textarea')
$inputs-height: 38px

// CSS Transition
$css-ease: ease !default
$css-time: .35s !default
