COLOMBIA = 57
ARGENTINA = 54
BOLIVIA = 591
CHILE = 56
COSTA_RICA = 506
CUBA = 53
DOMINICAN_REPUBLIC = 809
ECUADOR = 593
GUATEMALA = 502
MEXICO = 52
PERU = 51

CONTRY_CODE_CHOICES = (
    (COLOMBIA, f'+{COLOMBIA} - Colombia'),
    (ARGENTINA, f'+{ARGENTINA} - Argentina'),
    (BOLIVIA, f'+{BOLIVIA} - Bolivia'),
    (CHILE, f'+{CHILE} - Chile'),
    (COSTA_RICA, f'+{COSTA_RICA} - Costa rica'),
    (CUBA, f'+{CUBA} - Cuba'),
    (DOMINICAN_REPUBLIC, f'+{DOMINICAN_REPUBLIC} - Dominican republic'),
    (ECUADOR, f'+{ECUADOR} - Ecuador'),
    (GUATEMALA, f'+{GUATEMALA} - Guatemala'),
    (MEXICO, f'+{MEXICO} - México'),
    (PERU, f'+{PERU} - Perú'),
)
