{% extends 'otp_auth/base.html' %}
{% load widget_tweaks %}

{% block title %}Validación exitosa{% endblock %}

{% block body %}
<div class="message">
    {% include 'svg/_otp-success.html' with class='message__icon' %}
    <p class="message__text">Validación exitosa.</p>
    <h1 class="message__title">Bienvenido!</h1>
</div>
{% endblock %}

{% block js_globals %}
<script>
setTimeout(() => {
    window.opener.location.href = '{{ redirect|safe }}';
    window.close();
}, 1000);
</script>
{% endblock %}
