@font-face
  font-display: swap
  font-family: 'Proxima Nova'
  font-style: normal
  font-weight: 400
  src: url('../fonts/proxima-nova-regular.woff2') format('woff2'), url('../fonts/proxima-nova-regular.woff') format('woff')

@font-face
  font-display: swap
  font-family: 'Proxima Nova'
  font-style: normal
  font-weight: 700
  src: url('../fonts/proxima-nova-bold.woff2') format('woff2'), url('../fonts/proxima-nova-bold.woff') format('woff')
